@@ -8,10 +8,8 @@
 
 """Module tests."""
 
-from __future__ import absolute_import, print_function
-
 import pytest
-from flask import Flask
+from flask import Flask, current_app
 
 from invenio_files_rest import InvenioFilesREST
 
@@ -42,6 +40,16 @@ def test_alembic(app, db):
     if db.engine.name == 'sqlite':
         raise pytest.skip('Upgrades are not supported on SQLite.')
 
+    # skip index from alembic migrations until sqlalchemy 2.0
+    # https://github.com/sqlalchemy/sqlalchemy/discussions/7597
+    def include_object(object, name, type_, reflected, compare_to):
+        if name == 'ix_uq_partial_files_object_is_head':
+            return False
+
+        return True
+
+    current_app.config['ALEMBIC_CONTEXT'] = {'include_object': include_object}
+
     assert not ext.alembic.compare_metadata()
     db.drop_all()
     ext.alembic.upgrade()
