@@ -8,15 +8,12 @@
 
 """Module test views."""
 
-from __future__ import absolute_import, print_function
-
+import pytest
 import sys
 import uuid
+from fs.errors import ResourceNotFound
+from io import BytesIO
 from os.path import getsize
-
-import pytest
-from fs.errors import ResourceNotFoundError
-from six import BytesIO, b
 from sqlalchemy.exc import IntegrityError
 
 from invenio_files_rest.errors import BucketLockedError, \
@@ -26,6 +23,10 @@ from invenio_files_rest.models import Bucket, BucketTag, FileInstance, \
     Location, ObjectVersion, ObjectVersionTag
 
 
+def b(s):
+    return s.encode("latin-1")
+
+
 def test_location(app, db):
     """Test location model."""
     with db.session.begin_nested():
@@ -108,7 +109,7 @@ def test_bucket_create_object(app, db):
         assert b.default_location == Location.get_default().id
         assert b.location == Location.get_default()
         assert b.default_storage_class == \
-            app.config['FILES_REST_DEFAULT_STORAGE_CLASS']
+               app.config['FILES_REST_DEFAULT_STORAGE_CLASS']
         assert b.size == 0
         assert b.quota_size is None
         assert b.max_file_size is None
@@ -190,17 +191,17 @@ def test_object_create(app, db, dummy_location):
 
     # Object __repr__
     assert repr(obj1) == \
-        u"{0}:{1}:{2}".format(
-            obj1.bucket_id, obj1.version_id, obj1.key)
+           u"{0}:{1}:{2}".format(
+               obj1.bucket_id, obj1.version_id, obj1.key)
 
     if sys.version_info[0] >= 3:  # python3
         assert repr(obj4) == \
-            u"{0}:{1}:{2}".format(
-                obj4.bucket_id, obj4.version_id, obj4.key)
+               u"{0}:{1}:{2}".format(
+                   obj4.bucket_id, obj4.version_id, obj4.key)
     else:  # python2
         assert repr(obj4) == \
-            u"{0}:{1}:{2}".format(
-                obj4.bucket_id, obj4.version_id, obj4.key).encode('utf-8')
+               u"{0}:{1}:{2}".format(
+                   obj4.bucket_id, obj4.version_id, obj4.key).encode('utf-8')
 
     # Sanity check
     assert ObjectVersion.query.count() == 4
@@ -225,6 +226,27 @@ def test_object_create(app, db, dummy_location):
         obj3
 
 
+def test_object_create_uq_constraint(app, db, dummy_location):
+    """Test object creation unique constraint on is_head."""
+    # constraint is only enforced on postgresql
+    if db.engine.dialect.name != 'postgresql':
+        return
+
+    b = Bucket.create()
+
+    # Create 2 object version
+    obj1 = ObjectVersion(bucket=b, key="test", version_id=uuid.uuid4(), is_head=False, mimetype=None)
+    obj2 = ObjectVersion(bucket=b, key="test", version_id=uuid.uuid4(), is_head=True, mimetype=None)
+    db.session.add(obj1)
+    db.session.add(obj2)
+    db.session.commit()
+
+    # Create one invalid object version for same object key (is_head = True)
+    obj3 = ObjectVersion(bucket=b, key="test", version_id=uuid.uuid4(), is_head=True, mimetype=None)
+    db.session.add(obj3)
+    pytest.raises(IntegrityError, db.session.commit)
+
+
 def test_object_create_with_fileid(app, db, dummy_location):
     """Test object creation."""
     with db.session.begin_nested():
@@ -411,7 +433,7 @@ def test_object_set_contents(app, db, dummy_location):
     with db.session.begin_nested():
         obj2.file.checksum = old_checksum
         obj2.file.uri = 'invalid'
-    pytest.raises(ResourceNotFoundError, obj2.file.verify_checksum)
+    pytest.raises(ResourceNotFound, obj2.file.verify_checksum)
     assert obj2.file.last_check == previous_last_check
     assert obj2.file.last_check_at == previous_last_check_date
 
@@ -555,6 +577,42 @@ def test_bucket_sync_deleted_object(app, db, dummy_location):
     assert ObjectVersion.get_by_bucket(b2).count() == 0
 
 
+def test_bucket_sync_add_deleted_object(app, db, dummy_location):
+    """Test that adding back a deleted object in src is added in dest."""
+    b1 = Bucket.create()
+    b2 = Bucket.create()
+    obj1 = ObjectVersion.create(b1, "filename") \
+        .set_location("b1v1", 1, "achecksum")
+    ObjectVersion.create(b1, "filename2") \
+        .set_location("b1v2", 1, "achecksum2")
+
+    db.session.commit()
+
+    b1.sync(b2)
+
+    assert ObjectVersion.get_by_bucket(b1).count() == 2
+    assert ObjectVersion.get_by_bucket(b2).count() == 2
+
+    ObjectVersion.delete(b1, "filename")
+
+    db.session.commit()
+
+    b1.sync(b2)
+
+    assert ObjectVersion.get_by_bucket(b1).count() == 1
+    assert ObjectVersion.get_by_bucket(b2).count() == 1
+
+    # Add back obj1
+    ObjectVersion.create(b1, "filename", _file_id=obj1.file_id)
+
+    db.session.commit()
+
+    b1.sync(b2)
+
+    assert ObjectVersion.get_by_bucket(b1).count() == 2
+    assert ObjectVersion.get_by_bucket(b2).count() == 2
+
+
 def test_bucket_sync_delete_extras(app, db, dummy_location):
     """Test that an extra object in dest is deleted when syncing."""
     b1 = Bucket.create()
@@ -954,7 +1012,7 @@ def test_object_version_tags(app, db, dummy_location):
     assert ObjectVersionTag.query.count() == 2
     assert ObjectVersionTag.get(obj1, "mykey").value == "testvalue"
     assert ObjectVersionTag.get_value(obj1.version_id, "another_key") \
-        == "another value"
+           == "another value"
     assert ObjectVersionTag.get_value(obj1, "invalid") is None
 
     # Test delete
