@@ -9,7 +9,7 @@
 """Test file signals."""
 
 from flask import url_for
-from six import BytesIO
+from io import BytesIO
 from testutils import login_user
 
 from invenio_files_rest.signals import file_deleted, file_uploaded
@@ -25,10 +25,10 @@ def test_signals(app, client, headers, bucket, permissions):
 
     calls = []
 
-    def upload_listener(obj):
+    def upload_listener(sender, obj=None):
         calls.append("file-uploaded")
 
-    def delete_listener(obj):
+    def delete_listener(sender, obj=None):
         calls.append("file-deleted")
 
     file_uploaded.connect(upload_listener, weak=False)
